#!/usr/bin/env python

# standard library imports

# third party related imports

# local library imports


class Url(object):

    def __init__(self, url):

        self.proto = 'http://'
        self.url = url