#!/usr/bin/env python

# standard library imports

# third party related imports

# local library imports


class Mail(object):

    def __init__(self, mail):

        self.proto = 'mailto:'
        self.url = mail